#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Drawing;
using HeuristicLab.Collections;

namespace HeuristicLab.Clients.OKB.AdminService {
  public class EntityCollection<T> : ObservableCollection<T>, IEntityCollection<T> where T : class, IEntity {
    public virtual Image EntityImage {
      get { return HeuristicLab.Common.Resources.VS2008ImageLibrary.Class; }
    }

    public EntityCollection() : base() { }
    public EntityCollection(int capacity) : base(capacity) { }
    public EntityCollection(IEnumerable<T> collection) : base(collection) { }

    public new ReadOnlyEntityCollection<T> AsReadOnly() {
      return new ReadOnlyEntityCollection<T>(this);
    }

    public override string ToString() {
      return GetType().Name;
    }

    public event EventHandler EntityImageChanged;
    protected virtual void OnEntityImageChanged() {
      EventHandler handler = EntityImageChanged;
      if (handler != null) handler(this, EventArgs.Empty);
    }
    public event EventHandler ToStringChanged;
    protected virtual void OnToStringChanged() {
      EventHandler handler = ToStringChanged;
      if (handler != null) handler(this, EventArgs.Empty);
    }
  }
}
