#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.ComponentModel;
using System.Windows.Forms;
using HeuristicLab.Clients.OKB.AdminService;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Clients.OKB {
  [View("NamedEntoty View")]
  [Content(typeof(INamedEntity), false)]
  public partial class NamedEntityView : EntityView {
    public new INamedEntity Content {
      get { return (INamedEntity)base.Content; }
      set { base.Content = value; }
    }

    public NamedEntityView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.PropertyChanged -= new PropertyChangedEventHandler(Content_PropertyChanged);
      base.DeregisterContentEvents();
    }
    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.PropertyChanged += new PropertyChangedEventHandler(Content_PropertyChanged);
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        nameTextBox.Text = string.Empty;
        descriptionTextBox.Text = string.Empty;
        toolTip.SetToolTip(descriptionTextBox, string.Empty);
        if (ViewAttribute.HasViewAttribute(this.GetType()))
          this.Caption = ViewAttribute.GetViewName(this.GetType());
        else
          this.Caption = "NamedEntity View";
      } else {
        nameTextBox.Text = Content.Name;
        descriptionTextBox.Text = Content.Description;
        toolTip.SetToolTip(descriptionTextBox, Content.Description);
        Caption = Content.Name;
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      if (Content == null) {
        nameTextBox.Enabled = false;
        descriptionTextBox.Enabled = false;
      } else {
        nameTextBox.Enabled = true;
        nameTextBox.ReadOnly = ReadOnly;
        descriptionTextBox.Enabled = true;
        descriptionTextBox.ReadOnly = ReadOnly;
      }
    }

    protected virtual void Content_PropertyChanged(object sender, PropertyChangedEventArgs e) {
      if (InvokeRequired)
        Invoke(new PropertyChangedEventHandler(Content_PropertyChanged), sender, e);
      else {
        switch (e.PropertyName) {
          case "Name":
            nameTextBox.Text = Content.Name;
            Caption = Content.Name;
            break;
          case "Description":
            descriptionTextBox.Text = Content.Description;
            toolTip.SetToolTip(descriptionTextBox, Content.Description);
            break;
        }
        nameTextBox.Text = Content.Name;
        Caption = Content.Name;
      }
    }

    protected virtual void nameTextBox_KeyDown(object sender, KeyEventArgs e) {
      if ((e.KeyCode == Keys.Enter) || (e.KeyCode == Keys.Return))
        nameLabel.Focus();  // set focus on label to validate data
      if (e.KeyCode == Keys.Escape) {
        nameTextBox.Text = Content.Name;
        nameLabel.Focus();  // set focus on label to validate data
      }
    }
    protected virtual void nameTextBox_Validated(object sender, EventArgs e) {
      Content.Name = nameTextBox.Text;
    }
    protected virtual void descriptionTextBox_Validated(object sender, EventArgs e) {
      Content.Description = descriptionTextBox.Text;
    }

    protected void descriptionTextBox_DoubleClick(object sender, EventArgs e) {
      using (TextDialog dialog = new TextDialog("Description of " + Content.Name, descriptionTextBox.Text, ReadOnly)) {
        if (dialog.ShowDialog(this) == DialogResult.OK)
          Content.Description = dialog.Content;
      }
    }
  }
}
